==> touchstone-testing-1.2.0.tar.gz: touchstone-testing-1.2.0/touchstone/lib/mocks/networked_runnables/http/i_http_behavior.py <==
import abc


class IHttpSetup(object):
    @abc.abstractmethod
    def init(self, defaults: dict):
        pass

    @abc.abstractmethod
    def get(self, endpoint: str, response: str, response_status: int = 200,
            response_headers: dict = {'Content-Type': 'application/json'}):
        """Returns the given response when a GET request is made to the given endpoint."""
        pass

    @abc.abstractmethod
    def post(self, endpoint: str, response: str, response_status: int = 200,
             response_headers: dict = {'Content-Type': 'application/json'}):
        """Returns the given response when a POST request is made to the given endpoint."""
        pass

    @abc.abstractmethod
    def put(self, endpoint: str, response: str, response_status: int = 200,
            response_headers: dict = {'Content-Type': 'application/json'}):
        """Returns the given response when a PUT request is made to the given endpoint."""
        pass

    @abc.abstractmethod
    def delete(self, endpoint: str, response: str, response_status: int = 200,
               response_headers: dict = {'Content-Type': 'application/json'}):
        """Returns the given response when a DELETE request is made to the given endpoint."""
        pass


class IHttpVerify(object):
    def get_called(self, endpoint: str, times: int = 1) -> bool:
        """Returns True if the given endpoint has been called with a GET request the given number of times.
        If times is set to None, the endpoint can be called any number of times."""
        pass

    def post_called(self, endpoint: str, times: int = 1) -> bool:
        """Returns True if the given endpoint has been called with a POST request the given number of times.
        If times is set to None, the endpoint can be called any number of times."""
        pass

    def put_called(self, endpoint: str, times: int = 1) -> bool:
        """Returns True if the given endpoint has been called with a PUT request the given number of times.
        If times is set to None, the endpoint can be called any number of times."""
        pass

    def delete_called(self, endpoint: str, times: int = 1) -> bool:
        """Returns True if the given endpoint has been called with a DELETE request the given number of times.
        If times is set to None, the endpoint can be called any number of times."""
        pass

    def post_contained(self, endpoint: str, expected_body: str) -> bool:
        """Returns True if the given endpoint has been called with a POST request containing the given expected
        body."""
        pass

    def put_contained(self, endpoint: str, expected_body: str) -> bool:
        """Returns True if the given endpoint has been called with a PUT request containing the given expected
        body."""
        pass

    def delete_contained(self, endpoint: str, expected_body: str) -> bool:
        """Returns True if the given endpoint has been called with a DELETE request containing the given expected
        body."""
        pass


class IHttpBehavior(object):
    @abc.abstractmethod
    def setup(self) -> IHttpSetup:
        pass

    @abc.abstractmethod
    def verify(self) -> IHttpVerify:
        pass

    @abc.abstractmethod
    def url(self) -> str:
        """Returns the URL of this mocked HTTP resource."""
        pass

==> touchstone-testing-1.3.1.tar.gz: touchstone-testing-1.3.1/touchstone/lib/mocks/networked_runnables/http/i_http_behavior.py <==
import abc


class IHttpSetup(object):
    @abc.abstractmethod
    def get(self, endpoint: str, response: str, response_status: int = 200,
            response_headers: dict = {'Content-Type': 'application/json'}):
        """Returns the given response when a GET request is made to the given endpoint."""
        pass

    @abc.abstractmethod
    def post(self, endpoint: str, response: str, response_status: int = 200,
             response_headers: dict = {'Content-Type': 'application/json'}):
        """Returns the given response when a POST request is made to the given endpoint."""
        pass

    @abc.abstractmethod
    def put(self, endpoint: str, response: str, response_status: int = 200,
            response_headers: dict = {'Content-Type': 'application/json'}):
        """Returns the given response when a PUT request is made to the given endpoint."""
        pass

    @abc.abstractmethod
    def delete(self, endpoint: str, response: str, response_status: int = 200,
               response_headers: dict = {'Content-Type': 'application/json'}):
        """Returns the given response when a DELETE request is made to the given endpoint."""
        pass


class IHttpVerify(object):
    @abc.abstractmethod
    def get_called(self, endpoint: str, times: int = 1) -> bool:
        """Returns True if the given endpoint has been called with a GET request the given number of times.
        If times is set to None, the endpoint can be called any number of times."""
        pass

    @abc.abstractmethod
    def post_called(self, endpoint: str, times: int = 1) -> bool:
        """Returns True if the given endpoint has been called with a POST request the given number of times.
        If times is set to None, the endpoint can be called any number of times."""
        pass

    @abc.abstractmethod
    def post_contained(self, endpoint: str, expected_body: str) -> bool:
        """Returns True if the given endpoint has been called with a POST request containing the given expected
        body."""
        pass

    @abc.abstractmethod
    def post_contained_json(self, endpoint: str, expected_body: dict) -> bool:
        """Returns True if the given endpoint has been called with a POST request containing the given expected
        JSON body."""
        pass

    @abc.abstractmethod
    def put_called(self, endpoint: str, times: int = 1) -> bool:
        """Returns True if the given endpoint has been called with a PUT request the given number of times.
        If times is set to None, the endpoint can be called any number of times."""
        pass

    @abc.abstractmethod
    def put_contained(self, endpoint: str, expected_body: str) -> bool:
        """Returns True if the given endpoint has been called with a PUT request containing the given expected
        body."""
        pass

    @abc.abstractmethod
    def put_contained_json(self, endpoint: str, expected_body: dict) -> bool:
        """Returns True if the given endpoint has been called with a PUT request containing the given expected
        JSON body."""
        pass

    @abc.abstractmethod
    def delete_called(self, endpoint: str, times: int = 1) -> bool:
        """Returns True if the given endpoint has been called with a DELETE request the given number of times.
        If times is set to None, the endpoint can be called any number of times."""
        pass

    @abc.abstractmethod
    def delete_contained(self, endpoint: str, expected_body: str) -> bool:
        """Returns True if the given endpoint has been called with a DELETE request containing the given expected
        body."""
        pass

    @abc.abstractmethod
    def delete_contained_json(self, endpoint: str, expected_body: dict) -> bool:
        """Returns True if the given endpoint has been called with a DELETE request containing the given expected
        JSON body."""
        pass


class IHttpBehavior(object):
    @abc.abstractmethod
    def setup(self) -> IHttpSetup:
        pass

    @abc.abstractmethod
    def verify(self) -> IHttpVerify:
        pass

    @abc.abstractmethod
    def url(self) -> str:
        """Returns the URL of this mocked HTTP resource."""
        pass
